<?php
$TRANSLATIONS = array(
"Could not load template" => "No se cargó la plantilla",
"Saved" => "Guardado",
"Reset" => "Restablecer",
"An error occurred" => "Ocurrió un error",
"Sharing email - public link shares (HTML)" => "Compartir por correo electrónico - compartir enlace público (HTML) ",
"Sharing email - public link shares (plain text fallback)" => "Compartir por correo electrónico - compartir enlace público (texto plano)",
"Sharing email (HTML)" => "Compartir correo electrónico (HTML)",
"Sharing email (plain text fallback)" => "Compartir correo electrónico (texto plano)",
"Lost password mail" => "Correo electrónico - contraseña perdida",
"New user email (HTML)" => "Nueva dirección de correo electrónico del usuario (HTML)",
"New user email (plain text fallback)" => "Nuevo usuario de correo electrónico (texto plano)",
"Activity notification mail" => "Correo electrónico - notificación de actividad",
"Mail Templates" => "Plantillas de correo",
"Theme" => "Tema",
"Template" => "Plantilla",
"Please choose a template" => "Escoja una plantilla",
"Save" => "Guardar"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
